@@ -5,6 +5,7 @@ import redis
 from core.constants.not_available import NOT_AVAILABLE
 from core.number.BigFloat import BigFloat
 from core.options.exception.MissingOptionError import MissingOptionError
+from coreutility.json.json_utility import as_json, as_pretty_json
 
 T = TypeVar("T")
 
@@ -51,6 +52,10 @@ class RedisCacheProvider:
         if type(value) is BigFloat:
             self.log.debug(f'BigFloat storing key:{key} [{value}]')
             self.redis_client.set(key, str(value))
+        elif type(value) is dict:
+            self.log.debug(f'collection storing key:{key} [{value}]')
+            serialized_json = as_pretty_json(value, indent=None)
+            self.redis_client.set(key, serialized_json)
         else:
             self.log.debug(f'default storing key:{key} [{value}]')
             self.redis_client.set(key, value)
@@ -65,6 +70,10 @@ class RedisCacheProvider:
             return None if value is None else float(value)
         elif as_type is BigFloat:
             return None if value is None else BigFloat(value)
+        elif as_type is dict:
+            result = as_json(value)
+            self.log.debug(f'dict fetching key:{key} [{result}]')
+            return None if len(result) == 0 else result
         else:
             return value
 
